@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use 5.014;
 
-our $VERSION = '2.309';
+our $VERSION = '2.310';
 
 #use bytes; # required
 use Scalar::Util qw( looks_like_number );
@@ -98,7 +98,7 @@ sub get_schemas {
             }
             my $sth = $dbh->table_info( undef, '%', '', '' );
             my $info = $sth->fetchall_hashref( $TABLE_SCHEM );
-            for my $schema ( keys %$info ) {
+            for my $schema ( sort keys %$info ) {
                 if ( defined $regex_sys && $schema =~ $regex_sys ) {
                     push @$sys_schema, $schema;
                 }
@@ -162,17 +162,18 @@ sub get_databases {
 sub tables_info { # not public
     my ( $sf, $dbh, $schema ) = @_;
     my $tables_info = {};
-    # The table names in the $tables_info keys are used in the tables menu but not in SQL code. To get the table names
-    # for SQL code it is used the 'quote_table' routine.
+    # The table names in the $tables_info keys are used in the tables-menu but not in SQL code.
+    # To get the table names for SQL code it is used the 'quote_table' routine.
     my ( $table_schem, $table_name );
     if ( $sf->get_db_driver eq 'Pg' ) {
         $table_schem = 'pg_schema';
         $table_name  = 'pg_table';
-        # DBD::Pg  3.7.4:
+        # DBD::Pg  3.16.0:
         # The TABLE_SCHEM and TABLE_NAME will be quoted via quote_ident().
-        # Two additional fields specific to DBD::Pg are returned:
+        # Four additional fields specific to DBD::Pg are returned:
         # pg_schema: the unquoted name of the schema
         # pg_table: the unquoted name of the table
+        # ...
     }
     else {
         $table_schem = 'TABLE_SCHEM';
@@ -181,7 +182,6 @@ sub tables_info { # not public
     my @keys = ( 'TABLE_CAT', $table_schem, $table_name, 'TABLE_TYPE' );
     my $sth = $dbh->table_info( undef, $schema, '%', '' );
     my $info_tables = $sth->fetchall_arrayref( { map { $_ => 1 } @keys } );
-    my %equal_table_names;
     for my $info_table ( @$info_tables ) {
         next if $info_table->{TABLE_TYPE} eq 'INDEX';
         next if $info_table->{TABLE_TYPE} =~ /^SYSTEM/ && ! $sf->{Plugin}{o}{G}{metadata};
@@ -255,6 +255,19 @@ sub first_column_is_autoincrement {
         my ( $first_col_is_autoincrement ) = $dbh->selectrow_array( $sql, {}, $table );
         return $first_col_is_autoincrement;
     }
+    #elsif ( $sf->get_db_driver eq 'DB2' ) {
+    #    my $sql = "SELECT COUNT(*) FROM SYSCAT.COLUMNS WHERE
+    #            TABSCHEMA = ?
+    #        AND TABNAME = ?
+    #        AND COLNO = 0
+    #        AND TYPENAME = 'INTEGER'
+    #        AND NULLS = 'N'
+    #        AND KEYSEQ = 1
+    #        AND GENERATED = 'A'
+    #        AND IDENTITY = 'Y'";
+    #    my ( $first_col_is_autoincrement ) = $dbh->selectrow_array( $sql, {}, $schema, $table );
+    #    return $first_col_is_autoincrement;
+    #}
     return;
 }
 
@@ -289,6 +302,10 @@ sub primary_key_autoincrement_constraint {
             return "INT GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY";
         }
     }
+    #if ( $sf->get_db_driver eq 'DB2' ) {
+    #    #return "INT NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 1 INCREMENT BY 1) PRIMARY KEY";
+    #    return "INT NOT NULL GENERATED ALWAYS AS IDENTITY PRIMARY KEY";
+    #}
 }
 
 
@@ -310,7 +327,7 @@ App::DBBrowser::DB - Database plugin documentation.
 
 =head1 VERSION
 
-Version 2.309
+Version 2.310
 
 =head1 DESCRIPTION
 
